@@ -1,10 +1,11 @@
 from abstract_utilities import safe_json_loads,make_list,os,get_any_value
-from .responseContentParser import get_updated_response_content,get_file_path,get_title
+from abstract_ai.specializations.responseContentParser import get_updated_response_content,get_file_path,get_title
 from abstract_database import ensure_db_manager,flatten_json,pd
 from abstract_apis import get_async_response
 from abstract_pandas import safe_excel_save
 import asyncio,logging
 from concurrent.futures import ThreadPoolExecutor
+from abstract_database import *
 logging.basicConfig(
     level=logging.INFO,                     # Set the logging level (INFO, in this case)
     format='%(asctime)s - %(levelname)s - %(message)s',  # Log format
@@ -28,7 +29,7 @@ def extract_query(database_query):
                 return value
     return None
 
-from ..gpt_classes.nogui_selection.general_query import make_general_query
+from abstract_ai.gpt_classes.nogui_selection.general_query import make_general_query
 async def async_safe_excel_save(df, original_file_path, index=False, suffix=None, engine=None):
     """
     Asynchronous wrapper for safe_excel_save, running it in an executor.
@@ -53,12 +54,24 @@ async def save_to_excel_async(rows, file_path="output.xlsx"):
         # Use the asynchronous safe save function
         await async_safe_excel_save(df, file_path)
         logging.info(f"Excel file saved asynchronously to {file_path}.")
+def search_multiple(query,conn):
+
+    cur = conn.cursor()
+    try:
+        cur.execute(**query)
+        results = cur.fetchall()
+        return results
+    except psycopg2.Error as e:
+        print(f"Error querying JSONB data: {e}")
+    finally:
+        cur.close()
+        conn.close()
 async def search_multiple_fields(query_result=None,db_mgr=None,env_path=None,dbType=None,dbName=None,conn_mgr=None):
-    db_mgr = ensure_db_manager(db_mgr=db_mgget_auto_db_queryr,env_path=env_path,dbType=dbType,dbName=dbName,conn_mgr=conn_mgr)
+    db_mgr = ensure_db_manager(db_mgr=db_mgr,env_path=env_path,dbType=dbType,dbName=dbName,conn_mgr=conn_mgr)
     message = f"query successful"
     error=False
     try:
-        response = db_mgr.search_multiple_fields(**query_result)
+        response = search_multiple(query_result,conn_mgr.connect_db())
     except Exception as e:
         response = None
         message=f"the query with query_result: {query_result} errored with: {e}"
@@ -84,7 +97,7 @@ async def async_get_auto_db_query(prompt, tableName, db_mgr=None, env_path=None,
     
     # Get the raw AI response
     raw_response = await async_get_raw_response_for_query(prompt, tableName, db_mgr=db_mgr)
-    
+  
     # Update the response content
     response_content = get_updated_response_content(data=raw_response)
     
@@ -101,14 +114,16 @@ async def async_get_auto_db_query(prompt, tableName, db_mgr=None, env_path=None,
     
     # Run the query using the extracted query_result
     query_response = await search_multiple_fields(query_result={"query": query_result}, db_mgr=db_mgr, env_path=env_path, dbType=dbType, dbName=dbName, conn_mgr=conn_mgr)
-    
     # If query was successful, save the results to an Excel file
-    if query_response.get('error') == False:
+    if query_response.get('error') in [False,None] :
         await save_to_excel_async(rows=query_response.get('response'), file_path=xlsx_file_path)
     
     # Update the response with query response
     response_content.update(query_response)
     return response_content
-
 def get_auto_db_query(prompt,tableName,db_mgr=None,env_path=None,dbType=None,dbName=None,conn_mgr=None):
+    db_mgr = ensure_db_manager(db_mgr=db_mgr, env_path=env_path, dbType=dbType, dbName=dbName, conn_mgr=conn_mgr)
+    if conn_mgr == None:
+        conn_mgr = db_mgr.conn_mgr
+    prompt+='''\n\n###EXTRA DATABASE INSTRUCTION###\n\nt. the time is '''+f"{time.time()}\n"+'''Always include a 'query' key containing the SQL query as a string. Example: {\"query\": \"SELECT * FROM table WHERE condition\"}. Ensure that the 'query' key is always present in the database_query object, and the query is valid SQL.\n\n"'''
     return get_async_response(async_get_auto_db_query,prompt,tableName,db_mgr=db_mgr,env_path=env_path,dbType=dbType,dbName=dbName,conn_mgr=conn_mgr)
